/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.rat.mp;

import javax.inject.Named;

import org.apache.rat.configuration.builders.RegexBuilder;

/**
 *  @deprecated use Configuration file to define licenses
 */
@Deprecated
public class Regex extends RegexBuilder {

    @Named("expr")
    public RegexBuilder setExpression(String expression) {
        System.out.format("Calling setText() with %s\n", expression);
        return super.setExpression(expression);
    }
    public void set(String exp) {
        System.out.format("Calling set() with %s\n", exp);
        setExpression(exp);
    }

}
